Examples
========

Basic usage of ``loky``



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example highlights the ``loky`` API to reuse a ``ReusableProcessPool``.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_reuse_executor_thumb.png

        :ref:`sphx_glr_auto_examples_reuse_executor.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/reuse_executor
.. raw:: html

    <div style='clear:both'></div>

Deadlocks
---------

List the possible deadlock for ``concurrent.futures.ProcessPoolExecutor``
which are fixed in ``loky``.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example highlights the fact that the ProcessPoolExecutor implementation from concurrent.fu...">

.. only:: html

    .. figure:: /auto_examples/deadlocks/images/thumb/sphx_glr_deadlock_on_shutdown_thumb.png

        :ref:`sphx_glr_auto_examples_deadlocks_deadlock_on_shutdown.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/deadlocks/deadlock_on_shutdown

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example highlights the fact that the ProcessPoolExecutor implementation from concurrent.fu...">

.. only:: html

    .. figure:: /auto_examples/deadlocks/images/thumb/sphx_glr_deadlock_on_failed_pickle_thumb.png

        :ref:`sphx_glr_auto_examples_deadlocks_deadlock_on_failed_pickle.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/deadlocks/deadlock_on_failed_pickle
.. raw:: html

    <div style='clear:both'></div>



.. container:: sphx-glr-footer


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//home/tom/Work/prog/loky/docs/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//home/tom/Work/prog/loky/docs/auto_examples/auto_examples_jupyter.zip>`

.. rst-class:: sphx-glr-signature

    `Generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
